SnoopPacket

Struct SnoopPacket 

pub struct SnoopPacket {
    pub is_received: Option<bool>,
    pub format: Option<PacketFormat>,
    pub timestamp: Option<i64>,
    pub length: Option<u32>,
    pub data: Option<Vec<u8>>,
    /* private fields */
}

Fields

is_received: Option<bool>

true if this packet is sent from the controller to the host. Always present.

format: Option<PacketFormat>

Packet format, determined by the transport. Always present.

timestamp: Option<i64>

Timestamp that the snoop service received the packet from a transport as measured by the host system, in system monotonic time.

length: Option<u32>

Length of the packet. This may differ from the length of data as payloads can be truncated for storage reasons.

data: Option<Vec<u8>>

Packet data. This may be truncated, but if non-empty contains the packet data starting from the beginning.